"use client";
import { format } from "date-fns";
import { ChevronLeft, ChevronRight, Loader2 } from "lucide-react";
import { useLocale, useTranslations } from "next-intl";
import { useState, useTransition } from "react";

import {
	ColumnDefinition,
	CustomDataTable,
} from "@/components/common/table/cutom-data-table";
import InvoiceDetails from "@/components/sections/cart/invoice-details";
import BlurFade from "@/components/ui/blur-fade";
import { Button } from "@/components/ui/button";
import {
	Dialog,
	DialogContent,
	DialogHeader,
	DialogTitle,
	DialogTrigger,
} from "@/components/ui/dialog";
import { Tooltip, TooltipContent, TooltipProvider, TooltipTrigger } from "@/components/ui/tooltip";
import { cn } from "@/lib/utils";
import { reorderCart } from "@/servers/actions/cart-action";
import { restoreOrder } from "@/servers/actions/checkout-action";
import { usePaginatedOrders } from "@/servers/data/use-order";
import { Icon } from "@iconify/react/dist/iconify.js";
import { useRouter } from "next/navigation";
import { toast } from "sonner";

type Purchase = {
	id: number;
	status: string;
	payment_status: string;
	area: {
		id: number;
		name_ar: string;
		name_en: string;
	};
	city: {
		id: number;
		name_ar: string;
		name_en: string;
	};
	address: string;
	subtotal: number;
	created_at: string;
};

// pending || shipped || delivered || cancelled
const statusColors = {
	paid: "bg-[#CFF1E6] text-[#11B981]",
	pending: "bg-[#F9E0D2] text-[#E56A2F]",
	shipped: "bg-[#F9D2DA] text-[#E11D48]",
	delivered: "bg-[#CFF1E6] text-[#11B981]",
	cancelled: "bg-[#E9ECEF] text-[#6C757D]",
};

interface ActionButtonProps {
	icon: string;
	label: string;
	onClick?: () => void;
	disabled?: boolean;
	isLoading?: boolean;
	className?: string;
	iconClassName?: string;
}


const ActionButton = ({
	icon,
	label,
	onClick,
	disabled,
	isLoading,
	className = "h-[31px] w-[75px] rounded-sm text-sm text-[#6C757D]",
	iconClassName
}: ActionButtonProps) => {
	return (
		<TooltipProvider>
			<Tooltip>
				<TooltipTrigger asChild>
					<button
						className={className}
						onClick={onClick}
						disabled={disabled}
					>
						{isLoading ? (
							<Loader2 className="w-6 h-6 animate-spin" />
						) : (
							<Icon icon={icon} className={`w-6 h-6 ${iconClassName}`} />
						)}
					</button>
				</TooltipTrigger>
				<TooltipContent>
					<p>{label}</p>
				</TooltipContent>
			</Tooltip>
		</TooltipProvider>
	);
};

export default function PurchaseTable() {
	const t = useTranslations("UserAccount");
	const locale = useLocale();
	const router = useRouter();

	const [isPending, startTransition] = useTransition();
	const [loadingOrderId, setLoadingOrderId] = useState<number | null>(null);
	const [loadingRestoreId, setLoadingRestoreId] = useState<number | null>(null);
	const [selectedOrder, setSelectedOrder] = useState<Purchase | null>(null);

	const [currentPage, setCurrentPage] = useState(1);
	const [statusFilter, setStatusFilter] = useState<string | undefined>(undefined);
	const itemsPerPage = 10;

	// Use the hook with proper parameters
	const { orders, isLoading, isError, totalItems, totalPages } = usePaginatedOrders(
		currentPage,
		itemsPerPage,
		statusFilter
	);

	// Calculate pagination
	const startIndex = (currentPage - 1) * itemsPerPage;
	const endIndex = startIndex + itemsPerPage;
	const currentPurchases = orders?.slice(startIndex, endIndex) || [];

	const handlePreviousPage = () => {
		setCurrentPage((prev) => Math.max(prev - 1, 1));
	};

	const handleNextPage = () => {
		setCurrentPage((prev) => Math.min(prev + 1, totalPages));
	};

	const handleStatusChange = (value: string) => {
		setStatusFilter(value === "all" ? undefined : value);
		setCurrentPage(1); // Reset to first page when filter changes
	};

	const handleReorder = async (orderId: number) => {
		setLoadingOrderId(orderId);
		startTransition(async () => {
			console.log("reorderCart for order:", orderId);
			// Simulate API call
			const response = await reorderCart(orderId);
			console.log("response: ", response);
			if (response.success) {
				toast.success(t("Order reordered successfully"));
				setLoadingOrderId(null);
			} else {
				toast.error(t("Failed to reorder order"));
				setLoadingOrderId(null);
			}
		});
	};

	const handleRestore = async (orderId: number) => {
		console.log("restore order:", orderId);
		setLoadingRestoreId(orderId);
		startTransition(async () => {
			console.log("restore order:", orderId);
			const response = await restoreOrder({
				order_id: orderId,
				payment_callback_url: "https://bin-taleb-8jor.vercel.app/ar/cart?tab=2&status=restore"
			});
			console.log("response: ", response);
			if (response?.success) {
				toast.success(t("The payment link was created successfully"), {
					style: { backgroundColor: "green", color: "white" },
				});
				setLoadingRestoreId(null);
				router.push(response?.payment_url);
			} else {
				toast.error(t("Failed to restore order"));
				setLoadingRestoreId(null);
			}
		});
	};

	const handleDetails = (order: Purchase) => {
		setSelectedOrder(order);
	};

	const transformOrderToInvoiceDetails = (order: any) => {
		return {
			id: order?.id,
			payment_status: order?.payment_status,
			status: order?.status,
			first_name: order?.first_name,
			middle_name: order?.middle_name,
			last_name: order?.last_name,
			phone: order?.phone,
			city: { name: locale === "ar" ? order?.city?.name_ar : order?.city?.name_en },
			area: { name: locale === "ar" ? order?.area?.name_ar : order?.area?.name_en },
			address: order?.address,
			subtotal: order?.subtotal,
			delivery_price: order?.delivery_price,
			vat_value: order?.vat_value,
			total_price: order?.grand_total
		};
	};



	const columns: ColumnDefinition<Purchase>[] = [
		{
			header: t("Order status"),
			key: "status",
			align: "center",
			render: (value: any, row: any) => (
				<div
					className={`w-fit rounded-3xl px-2 py-1 text-[12px] leading-[18px] ${statusColors[row?.status as keyof typeof statusColors]}`}
				>
					{t(row?.status)}
				</div>
			),
		},
		{
			header: t("Payment status"),
			key: "payment_status",
			align: "center",
			render: (value: any, row: any) => (
				<div
					className={`w-fit rounded-3xl px-2 py-1 text-[12px] leading-[18px] ${statusColors[row?.payment_status as keyof typeof statusColors]}`}
				>
					{t(row?.payment_status)}
				</div>
			),
		},
		{
			header: t("Area"),
			key: "area",
			align: "center",
			render: (value: any, row: any) => (
				<span className="text-custom-fourth">
					{locale === "ar" ? row?.area?.name_ar : row?.area?.name_en}
				</span>
			),
		},
		{
			header: t("City"),
			key: "city",
			align: "center",
			render: (value: any, row: any) => (
				<span className="text-custom-fourth">
					{locale === "ar" ? row?.city?.name_ar : row?.city?.name_en}
				</span>
			),
		},
		{
			header: t("Total"),
			key: "subtotal",
			align: "center",
			render: (value: any, row: any) => (
				<p className="text-custom-fourth">
					{`${row?.subtotal.toFixed(2)} SAR`}
				</p>
			),
		},
		{
			header: t("Date"),
			key: "created_at",
			align: "center",
			render: (value: any, row: any) => (
				<>
					<p dir="ltr" className="mb-1 text-custom-fourth">
						{format(new Date(row?.created_at), "dd MMM, yyyy")}
					</p>
					<p dir="ltr" className="text-[12px] text-custom-fifth">
						{format(new Date(row?.created_at), "hh:mm a")}
					</p>
				</>
			),
		},
		{
			header: t("Actions"),
			key: "action",
			align: "center",
			render: (value: any, row: any) => (
				<div className={cn("flex gap-5 mx-auto w-[100px]")}>
					<ActionButton
						icon="tabler:file-invoice-filled"
						label={t("View invoice")}
						className="h-[31px] w-[75px] rounded-sm text-sm text-[#6C757D]"
						iconClassName="text-green-500"
					/>

					<ActionButton
						icon="f7:cart-badge-plus"
						label={t("Reorder")}
						onClick={() => handleReorder(row.id)}
						disabled={loadingOrderId === row.id}
						isLoading={loadingOrderId === row.id}
						iconClassName="text-custom-primary-accent"
					/>

					<Dialog>
						<DialogTrigger asChild>
							<ActionButton
								icon="stash:billing-info"
								label={t("Details")}
								onClick={() => handleDetails(row)}
								iconClassName="text-black"
							/>
						</DialogTrigger>
						<DialogContent className="sm:max-w-[600px]" dir="rtl">
							<DialogHeader>
								<DialogTitle>{t("Order Details")}</DialogTitle>
							</DialogHeader>
							{selectedOrder && (
								<InvoiceDetails orderInfo={transformOrderToInvoiceDetails(selectedOrder)} />

							)}
						</DialogContent>
					</Dialog>

					{row?.payment_status === "pending" && (
						<ActionButton
							icon="fluent:payment-24-filled"
							label={t("Complete payment")}
							onClick={() => handleRestore(row.id)}
							disabled={loadingRestoreId === row.id}
							isLoading={loadingRestoreId === row.id}
							iconClassName="text-red-500"
						/>
					)}
				</div>
			),
		}
	];

	return (
		<BlurFade direction="down" delay={0.25} inView>
			{/*<div className="mb-7 flex items-center justify-between">
				<p className="text-2xl font-semibold text-custom-fourth">{t("PurchaseHistory")}</p>
				<div className="flex items-center gap-2">
					<span className="text-sm text-custom-fifth">{t("FilterByStatus")}:</span>
					<Select
						value={statusFilter || "all"}
						onValueChange={handleStatusChange}
					>
						<SelectTrigger className="w-[180px]">
							<SelectValue placeholder={t("SelectStatus")} />
						</SelectTrigger>
						<SelectContent>
							<SelectItem value="all">{t("All")}</SelectItem>
							<SelectItem value="pending">{t("pending")}</SelectItem>
							<SelectItem value="shipped">{t("shipped")}</SelectItem>
							<SelectItem value="delivered">{t("delivered")}</SelectItem>
							<SelectItem value="cancelled">{t("cancelled")}</SelectItem>
						</SelectContent>
					</Select>
				</div>
			</div>*/}
			{
				isLoading ?
					<Loader2 className="mx-auto w-4 h-4 animate-spin" />
					:
					isError ?
						<p className="flex justify-center items-center h-64 text-custom-fourth">{t("Something went wrong")}</p>
						:
						orders?.length > 0 ? <div className="space-y-4">
							<CustomDataTable columns={columns} data={currentPurchases} locale={locale} />
							{totalPages > 1 && (
								<div className="flex items-center justify-between px-2">
									<div className="text-sm text-custom-fifth">
										{t("Showing")} {startIndex + 1}-{Math.min(endIndex, totalItems)} {t("of")} {totalItems}
									</div>
									<div className="flex items-center space-x-2">
										<Button
											variant="outline"
											size="sm"
											onClick={handlePreviousPage}
											disabled={currentPage === 1}
										>
											<ChevronLeft className="h-4 w-4" />
										</Button>
										<span className="text-sm text-custom-fifth">
											{t("Page")} {currentPage} {t("of")} {totalPages}
										</span>
										<Button
											variant="outline"
											size="sm"
											onClick={handleNextPage}
											disabled={currentPage === totalPages}
										>
											<ChevronRight className="h-4 w-4" />
										</Button>
									</div>
								</div>
							)}
						</div> :
							<div className="flex justify-center items-center h-64">
								{t("No purchases found")}
							</div>
			}
		</BlurFade >
	);
}
